==> haskell-hls-cabal-fmt-plugin-2.0.0.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.0.0.0-C7rlWTdBUvKD7OA3vwFjrj
key:                  hls-cabal-fmt-plugin-2.0.0.0-C7rlWTdBUvKD7OA3vwFjrj
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c119293c68f186d67d30e6142d920c49
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.0.0.0-C7rlWTdBUvKD7OA3vwFjrj
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.0-IQHZ41Bdb1tG2CG2PmBgb5
    hls-plugin-api-2.0.0.0-HXuoqsWA2vn6nZ63Ot0sEJ
    lens-5.2.3-FHiEVacHNvQGoO0ETRbZ1i
    lsp-types-1.6.0.1-Bdo3bouPeZkFEvvhlTYTVQ process-1.6.18.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-fmt-plugin-2.0.0.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.0.0.0-JW9NQVOZB8d2KlW4KfQx4
key:                  hls-cabal-fmt-plugin-2.0.0.0-JW9NQVOZB8d2KlW4KfQx4
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5cad1a17b77aa129111882d9f1e7935b
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.0.0.0-JW9NQVOZB8d2KlW4KfQx4
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.0-5kGJ3N88yWOKs0LdTuuBaf
    hls-plugin-api-2.0.0.0-4BDsfsO8yNxJwdG0ejP4Uf
    lens-5.2.3-FHiEVacHNvQGoO0ETRbZ1i
    lsp-types-1.6.0.1-Bdo3bouPeZkFEvvhlTYTVQ process-1.6.18.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
